%define major     1
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           zita-resampler
Version:        1.10.1
Release:        %mkrel 1
Summary:        Fast, high-quality sample rate conversion library
License:        GPLv3+
Group:          System/Libraries
# http://kokkinizita.linuxaudio.org/linuxaudio/index.html
URL:            https://kokkinizita.linuxaudio.org/linuxaudio/zita-resampler/resampler.html
Source0:        https://kokkinizita.linuxaudio.org/linuxaudio/downloads/%{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(sndfile)

%description
zita-resampler is a C++ library for resampling audio signals. It is
designed to be used within a real-time processing context, to be fast,
and to provide high-quality sample rate conversion.

The library operates on signals represented in single-precision
floating point format. For multichannel operation both the input and
output signals are assumed to be stored as interleaved samples.

The API allows a trade-off between quality and CPU load. For the
latter a range of approximately 1:6 is available. Even at the highest
quality setting zita-resampler will be faster than most similar
libraries, e.g. libsamplerate.

%package -n     %{libname}
Summary:        Fast, high-quality sample rate conversion library
Group:          System/Libraries

%description -n %{libname}
zita-resampler is a C++ library for resampling audio signals. It is
designed to be used within a real-time processing context, to be fast,
and to provide high-quality sample rate conversion.

The library operates on signals represented in single-precision
floating point format. For multichannel operation both the input and
output signals are assumed to be stored as interleaved samples.

The API allows a trade-off between quality and CPU load. For the
latter a range of approximately 1:6 is available. Even at the highest
quality setting zita-resampler will be faster than most similar
libraries, e.g. libsamplerate.

%package -n     %{develname}
Summary:        Development libraries and headers for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the headers and development libraries for %{name}.

%prep
%autosetup -p1

# To make sure to have the correct Mageia specific flags:
sed -i -e 's|-O[23]||' -e 's|ldconfig||' -e 's|-march=native||' -e '/^CPPFLAGS += -DENABLE_SSE2/d' source/Makefile
sed -i -e 's|-O[23]||' -e 's|-march=native||' apps/Makefile

%build
%set_build_flags

# Enable SSE2 on x86_64
%ifarch x86_64
CPPFLAGS+=" -DENABLE_SSE2"
export CPPFLAGS
%endif

%make_build -C source
# In order to build apps, we need to create the symlink
# Note that this is originally done at "make install" stage
ln -sf libzita-resampler.so.%{version} source/libzita-resampler.so

CXXFLAGS+=" -I../source"
LDFLAGS+=" -L../source"
%make_build -C apps

%install
%make_install -C source PREFIX=%{_prefix} LIBDIR=%{_libdir}
%make_install -C apps PREFIX=%{_prefix} LIBDIR=%{_libdir}

chmod 0755 %{buildroot}%{_libdir}/lib%{name}.so.%{version}

%files
%doc AUTHORS
%license COPYING
%{_bindir}/zresample
%{_bindir}/zretune
%{_mandir}/man1/zresample.1.*
%{_mandir}/man1/zretune.1.*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc docs/*
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so


%changelog
* Sat Feb 18 2023 daviddavid <daviddavid> 1.10.1-1.mga9
+ Revision: 1943974
- new version: 1.10.1

* Sat Mar 26 2022 umeabot <umeabot> 1.8.0-2.mga9
+ Revision: 1828388
- Mageia 9 Mass Rebuild

* Mon Jan 04 2021 daviddavid <daviddavid> 1.8.0-1.mga8
+ Revision: 1668555
- new version: 1.8.0

* Sun Feb 16 2020 umeabot <umeabot> 1.6.2-2.mga8
+ Revision: 1533578
- Mageia 8 Mass Rebuild

* Mon Sep 23 2019 daviddavid <daviddavid> 1.6.2-1.mga8
+ Revision: 1444740
- initial package zita-resampler (from fedora)

